@@ -552,6 +552,8 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 int
 main (int argc, char *argv[])
 {
+	GnomeProgram *program;
+	GOptionContext *context;
 	GConfClient *client;
 	GFloppyConfig config;
 	GtkWidget *fs_entry;
@@ -566,24 +568,28 @@ main (int argc, char *argv[])
 	/* This is for the libhal context, should we need it */
 	gpointer ctx;
 
-	struct poptOption gfloppy_opts[] = {
-		{"device", '\0', POPT_ARG_STRING, NULL, 0, NULL, NULL},
-		{NULL, '\0', 0, NULL, 0, NULL, NULL}
-	};
-
 	floppy.device = NULL;
-	gfloppy_opts[0].arg = &(floppy.device);
-	gfloppy_opts[0].descrip = _("The device to format");
-	gfloppy_opts[0].argDescrip = _("DEVICE");
+
+	static const GOptionEntry options[] =  {
+	  { "device", 0, 0, G_OPTION_ARG_STRING, &(floppy.device),
+	    N_("The device to format"), N_("DEVICE") },
+	  { NULL }
+	};
 
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_program_init ("gfloppy",VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv, GNOME_PARAM_POPT_TABLE, gfloppy_opts,
-                            GNOME_PARAM_POPT_FLAGS, 0,
-                            GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
+	context = g_option_context_new (_("- Floppy Formatter"));
+	
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
+	program = gnome_program_init
+	  (argv[0], VERSION, LIBGNOMEUI_MODULE,
+	   argc, argv,
+	   GNOME_PARAM_GOPTION_CONTEXT, context,
+	   GNOME_PARAM_APP_DATADIR,DATADIR,
+	   GNOME_PARAM_NONE);
 
 #ifdef USE_HAL
 	ctx = (gpointer)get_hal_context ();
@@ -736,6 +742,7 @@ main (int argc, char *argv[])
 	}
 #endif
 
+	g_object_unref (program);
 	return 0;
 }
 
