@@ -1212,13 +1212,25 @@ static void
 gdict_applet_init (GdictApplet *applet)
 {
   GdictAppletPrivate *priv;
-  gchar *icon_file, *data_dir;
+  gchar *data_dir, *icon_file;
   GdkPixbuf *icon;
   GError *icon_error, *gconf_error;
 
   priv = GDICT_APPLET_GET_PRIVATE (applet);
   applet->priv = priv;
       
+  data_dir = g_build_filename (g_get_home_dir (),
+  			       ".gnome2",
+  			       "gnome-dictionary",
+  			       NULL);
+  if (!priv->loader)
+    priv->loader = gdict_source_loader_new ();
+
+  /* add our data dir inside $HOME to the loader's search paths */
+  gdict_source_loader_add_search_path (priv->loader, data_dir);
+
+  g_free (data_dir);
+  
   icon_file = g_build_filename (DATADIR,
 		  		"pixmaps",
 				"gnome-dictionary.png",
@@ -1294,25 +1306,12 @@ gdict_applet_init (GdictApplet *applet)
       gconf_error = NULL;
     }
   
-  if (!priv->loader)
-    priv->loader = gdict_source_loader_new ();
-
-  data_dir = g_build_filename (g_get_home_dir (),
-		  	       ".gnome2",
-			       "gnome-dictionary",
-			       NULL);
-
-  /* add our data dir inside $HOME to the loader's search paths */
-  gdict_source_loader_add_search_path (priv->loader, data_dir);
-
-  g_free (data_dir);
-
 #ifndef GDICT_APPLET_STAND_ALONE
   panel_applet_set_background_widget (PANEL_APPLET (applet),
-				      GTK_WIDGET (applet));
-  
+		  		      GTK_WIDGET (applet));
+
   priv->size = panel_applet_get_size (PANEL_APPLET (applet));
-  
+
   switch (panel_applet_get_orient (PANEL_APPLET (applet)))
     {
     case PANEL_APPLET_ORIENT_LEFT:
@@ -1392,7 +1391,7 @@ gdict_applet_factory (PanelApplet *applet,
 
 /* create the data directory inside $HOME, if it doesn't exist yet */
 static gboolean
-gdict_applet_create_data_dir (void)
+gdict_applet_create_data_dir ()
 {
   gchar *data_dir_name;
   
@@ -1509,7 +1508,7 @@ main (int argc, char *argv[])
 		      NULL);
 
   if (!gdict_applet_create_data_dir ())
-    return FALSE;
+    return EXIT_FAILURE;
 
   return panel_applet_factory_main ("OAFIID:GNOME_DictionaryApplet_Factory",
 		                    GDICT_TYPE_APPLET,
@@ -1518,9 +1517,6 @@ main (int argc, char *argv[])
 #else
   gtk_init (&argc, &argv);
 
-  if (!gdict_applet_create_data_dir ())
-    return FALSE;
-  
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   g_signal_connect (window, "destroy", G_CALLBACK (gtk_main_quit), NULL);
 
